Python Module Index — PBI_dashboard_creator 1.0.62 documentation

# Python Module Index

p

| p |
| `PBI_dashboard_creator` |
| `PBI_dashboard_creator.add_ADLS_csv` |
| `PBI_dashboard_creator.add_background_image` |
| `PBI_dashboard_creator.add_button` |
| `PBI_dashboard_creator.add_local_csv` |
| `PBI_dashboard_creator.add_shape_map` |
| `PBI_dashboard_creator.add_text_box` |
| `PBI_dashboard_creator.add_tmdl` |
| `PBI_dashboard_creator.create_blank_dashboard` |
| `PBI_dashboard_creator.create_date_hrcy` |
| `PBI_dashboard_creator.create_new_chart` |
| `PBI_dashboard_creator.create_new_page` |
| `PBI_dashboard_creator.create_tmdl` |
| `PBI_dashboard_creator.update_diagramLayout` |
| `PBI_dashboard_creator.update_model_file` |